==> leonardo-0.4.0-rc1.tgz: leonardo-0.4.0-rc1/lib/core.py <==
#
#    Copyright (C) 2003-2004  James Tauber
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

import request_response
import filesystem

import providers.manager

import providers.static
import providers.css
import providers.login_logout
import providers.editform
import providers.put
import providers.blog
import providers.atom
import providers.draft
import providers.menu
import providers.page


def dispatcher(config):

    request = request_response.Request(config)

    lfs = filesystem.LeonardoFileSystem(config.lfs_root)

    # RESOURCE PROVIDERS
    resource_manager = providers.manager.ProviderManager()

    # menu provider
    menu_provider = providers.menu.MenuProvider(resource_manager, lfs, config)

    # register resource providers
    resource_manager.register_provider(providers.static.StaticFileProvider(config))
    resource_manager.register_provider(providers.css.CSSProvider(lfs, config))
    resource_manager.register_provider(providers.login_logout.LoginLogoutProvider(resource_manager, lfs, config))
    resource_manager.register_provider(providers.editform.EditFormProvider(resource_manager, lfs, config))
    resource_manager.register_provider(providers.put.PutProvider(resource_manager, lfs, config))
    resource_manager.register_provider(providers.blog.BlogProvider(resource_manager, lfs, config))
    resource_manager.register_provider(providers.atom.AtomProvider(resource_manager, lfs, config))
    resource_manager.register_provider(providers.draft.DraftProvider(resource_manager, lfs, config))
    resource_manager.register_provider(menu_provider)
    resource_manager.register_provider(providers.page.PageProvider(resource_manager, lfs, config))

    menu_provider.register_provider(providers.login_logout.menu_part)
    menu_provider.register_provider(providers.editform.edit_menu_part)
    menu_provider.register_provider(providers.draft.draft_menu_part)

    resource_id = request.relative_path
    
    resource = resource_manager.get(resource_id, request, None)


    # @@@ we could just pass the resource into the constructor
    response = request_response.Response()
    
    response.set_content_type(resource.get_mime_type())
    response.set_content(resource.get_content())
    
    # @@@ bit of a hack
    if hasattr(resource, "status"):
        response.set_status(resource.status)
    if hasattr(resource, "cookie"):
        response.set_cookie(resource.cookie)
    if hasattr(resource, "expiry"):
        response.set_header("Expiry", 0)
    
    response.send()

==> leonardo-0.5b1.tgz: leonardo-0.5b1/lib/core.py <==
#
#    Copyright (C) 2003-2004  James Tauber
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

import time

import request_response
import filesystem

import providers.manager

import providers.static
import providers.css
import providers.login_logout
import providers.editform
import providers.put
import providers.delete
import providers.blog
import providers.atom
import providers.draft
import providers.menu
import providers.page
import providers.enclosure
import providers.blogcalendar

def dispatcher(config):

    request = request_response.Request(config)

    lfs = filesystem.LeonardoFileSystem(config.lfs_root)

    # RESOURCE PROVIDERS
    resource_manager = providers.manager.ProviderManager()

    # menu provider
    menu_provider = providers.menu.MenuProvider(resource_manager, lfs, config)

    # register resource providers
    resource_manager.register_provider(providers.static.StaticFileProvider(config))
    resource_manager.register_provider(providers.enclosure.EnclosureProvider(lfs,config))
    resource_manager.register_provider(providers.css.CSSProvider(lfs, config))
    resource_manager.register_provider(providers.login_logout.LoginLogoutProvider(resource_manager, lfs, config))
    resource_manager.register_provider(providers.editform.EditFormProvider(resource_manager, lfs, config))
    resource_manager.register_provider(providers.put.PutProvider(resource_manager, lfs, config))
    resource_manager.register_provider(providers.delete.DeleteProvider(resource_manager, lfs, config))
    resource_manager.register_provider(providers.blog.BlogProvider(resource_manager, lfs, config))
    resource_manager.register_provider(providers.atom.AtomProvider(resource_manager, lfs, config))
    resource_manager.register_provider(providers.draft.DraftProvider(resource_manager, lfs, config))
    resource_manager.register_provider(providers.blogcalendar.CalendarProvider(config))
    resource_manager.register_provider(menu_provider)
    resource_manager.register_provider(providers.page.PageProvider(resource_manager, lfs, config))

    menu_provider.register_provider(providers.login_logout.menu_part)
    menu_provider.register_provider(providers.editform.edit_menu_part)
    menu_provider.register_provider(providers.delete.delete_menu_part)
    menu_provider.register_provider(providers.draft.draft_menu_part)

    resource_id = request.relative_path
    
    resource = resource_manager.get(resource_id, request, None)


    # @@@ we could just pass the resource into the constructor
    response = request_response.Response()
    
    response.set_content_type(resource.get_mime_type())
    response.set_content(resource.get_content())
    
    # @@@ bit of a hack
    if hasattr(resource, "status"):
        response.set_status(resource.status)
    if hasattr(resource, "cookie"):
        response.set_cookie(resource.cookie)
    if hasattr(resource, "expiry"):
        response.set_header("Expires", 0)
    if hasattr(resource, "lastmod"):
        response.set_header("Last-Modified", time.strftime("%a, %d %b %Y %H:%M:%S GMT", resource.lastmod))

        if request.if_modified_since:
            request_time = time.mktime(time.strptime(request.if_modified_since, "%a, %d %b %Y %H:%M:%S %Z"))
            if time.mktime(resource.lastmod) <= request_time:
                # send 304 instead
                response = request_response.Response()
                response.set_status("304 Not Modified")
    
    response.send()
